@@ -48,7 +48,7 @@ def keyentry(socket, display):
         # check if special cmd
         if read1 == "KEY_F(1)":
             read = "F1"
-        if read1 == "KEY_F(2)":
+        elif read1 == "KEY_F(2)":
             read = "F2"
         elif read1 == "KEY_F(3)":
             read = "F3"
@@ -134,7 +134,7 @@ def readmessage(socket, display):
                     elif "DISPLAY" in cmd:
                         output = cmd[8:]
                         display.addstr(y, x, output)
-                        display.move(y+1, 1)
+                        # display.move(y+1, 1)
                         display.refresh()
 
                     elif cmd == "BELL":
